/** @file
  Copyright (c) 2018 - 2019, Intel Corporation. All rights reserved.<BR>
  SPDX-License-Identifier: BSD-2-Clause-Patent

**/

/*
 * 
 * Intel ACPI Component Architecture
 * 
 * 
 */
#ifndef __AML_OFFSET_TABLE_H
#define __AML_OFFSET_TABLE_H

typedef struct {
    char                   *Pathname;      /* Full pathname (from root) to the object */
    unsigned short         ParentOpcode;   /* AML opcode for the parent object */
    unsigned long          NamesegOffset;  /* Offset of last nameseg in the parent namepath */
    unsigned char          Opcode;         /* AML opcode for the data */
    unsigned long          Offset;         /* Offset for the data */
    unsigned long long     Value;          /* Original value of the data (as applicable) */
} AML_OFFSET_TABLE_ENTRY;

#endif /* __AML_OFFSET_TABLE_H */

/*
 * Information specific to the supported object types:
 *
 * Integers:
 *    Opcode is the integer prefix, indicates length of the data
 *        (One of: BYTE, WORD, DWORD, QWORD, ZERO, ONE, ONES)
 *    Offset points to the actual integer data
 *    Value is the existing value in the AML
 *
 * Packages:
 *    Opcode is the package or var_package opcode
 *    Offset points to the package opcode
 *    Value is the package element count
 *
 * Operation Regions:
 *    Opcode is the address integer prefix, indicates length of the data
 *    Offset points to the region address
 *    Value is the existing address value in the AML
 *
 * Control Methods:
 *    Offset points to the method flags byte
 *    Value is the existing flags value in the AML
 *
 * Processors:
 *    Offset points to the first byte of the PBlock Address
 *
 * Resource Descriptors:
 *    Opcode is the descriptor type
 *    Offset points to the start of the descriptor
 *
 * Scopes/Devices/ThermalZones:
 *    Nameseg offset only
 */
AML_OFFSET_TABLE_ENTRY   DSDT_PLATWFP__OffsetTable[] =
{
    {"PSYS",                       0x5B80, 0x0000038B, 0x0C, 0x00000391, 0x0000000030584946}, /* OPERATIONREGION */
    {"_SB_.PC00.FIX1",             0x0011, 0x00000000, 0x88, 0x0000D187, 0x0000000000000000}, /* WORDBUSNUMBER */
    {"_SB_.PC00.FIX2",             0x0011, 0x00000000, 0x88, 0x0000D1AF, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC00.FIX5",             0x0011, 0x00000000, 0x87, 0x0000D1BF, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC00.FIX3",             0x0011, 0x00000000, 0x87, 0x0000D20D, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC00.FIX4",             0x0011, 0x00000000, 0x8A, 0x0000D227, 0x0000000000000000}, /* QWORDMEMORY */
    {"_SB_.PC01.FIX1",             0x0011, 0x00000000, 0x88, 0x0000EA9B, 0x0000000000000000}, /* WORDBUSNUMBER */
    {"_SB_.PC01.FIX5",             0x0011, 0x00000000, 0x87, 0x0000EAAB, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC01.FIX2",             0x0011, 0x00000000, 0x88, 0x0000EAC5, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC01.FIX6",             0x0011, 0x00000000, 0x88, 0x0000EAD5, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC01.FIX7",             0x0011, 0x00000000, 0x88, 0x0000EAE5, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC01.FIX3",             0x0011, 0x00000000, 0x87, 0x0000EAF5, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC01.FIX4",             0x0011, 0x00000000, 0x8A, 0x0000EB0F, 0x0000000000000000}, /* QWORDMEMORY */
    {"_SB_.PC01.BR1A.MCTL",        0x5B80, 0x0000EB91, 0x0C, 0x0000EB97, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC01.BR1B.MCTL",        0x5B80, 0x0000F3B2, 0x0C, 0x0000F3B8, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC01.BR1C.MCTL",        0x5B80, 0x0000FBD3, 0x0C, 0x0000FBD9, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC01.BR1D.MCTL",        0x5B80, 0x000103F4, 0x0C, 0x000103FA, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC02.FIX1",             0x0011, 0x00000000, 0x88, 0x00010E93, 0x0000000000000000}, /* WORDBUSNUMBER */
    {"_SB_.PC02.FIX5",             0x0011, 0x00000000, 0x87, 0x00010EA3, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC02.FIX2",             0x0011, 0x00000000, 0x88, 0x00010EBD, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC02.FIX6",             0x0011, 0x00000000, 0x88, 0x00010ECD, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC02.FIX7",             0x0011, 0x00000000, 0x88, 0x00010EDD, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC02.FIX3",             0x0011, 0x00000000, 0x87, 0x00010EED, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC02.FIX4",             0x0011, 0x00000000, 0x8A, 0x00010F07, 0x0000000000000000}, /* QWORDMEMORY */
    {"_SB_.PC02.BR2A.MCTL",        0x5B80, 0x00010F89, 0x0C, 0x00010F8F, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC02.BR2B.MCTL",        0x5B80, 0x00011969, 0x0C, 0x0001196F, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC02.BR2C.MCTL",        0x5B80, 0x0001218A, 0x0C, 0x00012190, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC02.BR2D.MCTL",        0x5B80, 0x000129AB, 0x0C, 0x000129B1, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC03.FIX1",             0x0011, 0x00000000, 0x88, 0x000133E4, 0x0000000000000000}, /* WORDBUSNUMBER */
    {"_SB_.PC03.FIX5",             0x0011, 0x00000000, 0x87, 0x000133F4, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC03.FIX2",             0x0011, 0x00000000, 0x88, 0x0001340E, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC03.FIX6",             0x0011, 0x00000000, 0x88, 0x0001341E, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC03.FIX7",             0x0011, 0x00000000, 0x88, 0x0001342E, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC03.FIX3",             0x0011, 0x00000000, 0x87, 0x0001343E, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC03.FIX4",             0x0011, 0x00000000, 0x8A, 0x00013458, 0x0000000000000000}, /* QWORDMEMORY */
    {"_SB_.PC03.BR3A.MCTL",        0x5B80, 0x000134DA, 0x0C, 0x000134E0, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC03.BR3B.MCTL",        0x5B80, 0x00013CFB, 0x0C, 0x00013D01, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC03.BR3C.MCTL",        0x5B80, 0x0001451C, 0x0C, 0x00014522, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC03.BR3D.MCTL",        0x5B80, 0x00014D3D, 0x0C, 0x00014D43, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC04.FIX1",             0x0011, 0x00000000, 0x88, 0x000156F0, 0x0000000000000000}, /* WORDBUSNUMBER */
    {"_SB_.PC04.FIX5",             0x0011, 0x00000000, 0x87, 0x00015700, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC04.FIX2",             0x0011, 0x00000000, 0x88, 0x0001571A, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC04.FIX6",             0x0011, 0x00000000, 0x88, 0x0001572A, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC04.FIX7",             0x0011, 0x00000000, 0x88, 0x0001573A, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC04.FIX3",             0x0011, 0x00000000, 0x87, 0x0001574A, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC04.FIX4",             0x0011, 0x00000000, 0x8A, 0x00015764, 0x0000000000000000}, /* QWORDMEMORY */
    {"_SB_.PC04.MCP0.MCTL",        0x5B80, 0x000157E6, 0x0C, 0x000157EC, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC05.FIX1",             0x0011, 0x00000000, 0x88, 0x0001612D, 0x0000000000000000}, /* WORDBUSNUMBER */
    {"_SB_.PC05.FIX5",             0x0011, 0x00000000, 0x87, 0x0001613D, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC05.FIX2",             0x0011, 0x00000000, 0x88, 0x00016157, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC05.FIX6",             0x0011, 0x00000000, 0x88, 0x00016167, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC05.FIX7",             0x0011, 0x00000000, 0x88, 0x00016177, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC05.FIX3",             0x0011, 0x00000000, 0x87, 0x00016187, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC05.FIX4",             0x0011, 0x00000000, 0x8A, 0x000161A1, 0x0000000000000000}, /* QWORDMEMORY */
    {"_SB_.PC05.MCP1.MCTL",        0x5B80, 0x00016223, 0x0C, 0x00016229, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC06.FIX1",             0x0011, 0x00000000, 0x88, 0x00016FD9, 0x0000000000000000}, /* WORDBUSNUMBER */
    {"_SB_.PC06.FIX5",             0x0011, 0x00000000, 0x87, 0x00016FE9, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC06.FIX2",             0x0011, 0x00000000, 0x88, 0x00017003, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC06.FIX6",             0x0011, 0x00000000, 0x88, 0x00017013, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC06.FIX7",             0x0011, 0x00000000, 0x88, 0x00017023, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC06.FIX3",             0x0011, 0x00000000, 0x87, 0x00017033, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC06.FIX4",             0x0011, 0x00000000, 0x8A, 0x0001704D, 0x0000000000000000}, /* QWORDMEMORY */
    {"_SB_.PC06.QRP0.MCTL",        0x5B80, 0x00017149, 0x0C, 0x0001714F, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC07.FIX1",             0x0011, 0x00000000, 0x88, 0x00017BC4, 0x0000000000000000}, /* WORDBUSNUMBER */
    {"_SB_.PC07.FIX5",             0x0011, 0x00000000, 0x87, 0x00017BD4, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC07.FIX2",             0x0011, 0x00000000, 0x88, 0x00017BEE, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC07.FIX6",             0x0011, 0x00000000, 0x88, 0x00017BFE, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC07.FIX7",             0x0011, 0x00000000, 0x88, 0x00017C0E, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC07.FIX3",             0x0011, 0x00000000, 0x87, 0x00017C1E, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC07.FIX4",             0x0011, 0x00000000, 0x8A, 0x00017C38, 0x0000000000000000}, /* QWORDMEMORY */
    {"_SB_.PC07.QR1A.MCTL",        0x5B80, 0x00017CCA, 0x0C, 0x00017CD0, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC07.QR1B.MCTL",        0x5B80, 0x00018506, 0x0C, 0x0001850C, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC07.QR1C.MCTL",        0x5B80, 0x00018D42, 0x0C, 0x00018D48, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC07.QR1D.MCTL",        0x5B80, 0x0001957E, 0x0C, 0x00019584, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC08.FIX1",             0x0011, 0x00000000, 0x88, 0x0001A04E, 0x0000000000000000}, /* WORDBUSNUMBER */
    {"_SB_.PC08.FIX5",             0x0011, 0x00000000, 0x87, 0x0001A05E, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC08.FIX2",             0x0011, 0x00000000, 0x88, 0x0001A078, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC08.FIX6",             0x0011, 0x00000000, 0x88, 0x0001A088, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC08.FIX7",             0x0011, 0x00000000, 0x88, 0x0001A098, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC08.FIX3",             0x0011, 0x00000000, 0x87, 0x0001A0A8, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC08.FIX4",             0x0011, 0x00000000, 0x8A, 0x0001A0C2, 0x0000000000000000}, /* QWORDMEMORY */
    {"_SB_.PC08.QR2A.MCTL",        0x5B80, 0x0001A154, 0x0C, 0x0001A15A, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC08.QR2B.MCTL",        0x5B80, 0x0001A990, 0x0C, 0x0001A996, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC08.QR2C.MCTL",        0x5B80, 0x0001B1CC, 0x0C, 0x0001B1D2, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC08.QR2D.MCTL",        0x5B80, 0x0001BA08, 0x0C, 0x0001BA0E, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC09.FIX1",             0x0011, 0x00000000, 0x88, 0x0001C461, 0x0000000000000000}, /* WORDBUSNUMBER */
    {"_SB_.PC09.FIX5",             0x0011, 0x00000000, 0x87, 0x0001C471, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC09.FIX2",             0x0011, 0x00000000, 0x88, 0x0001C48B, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC09.FIX6",             0x0011, 0x00000000, 0x88, 0x0001C49B, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC09.FIX7",             0x0011, 0x00000000, 0x88, 0x0001C4AB, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC09.FIX3",             0x0011, 0x00000000, 0x87, 0x0001C4BB, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC09.FIX4",             0x0011, 0x00000000, 0x8A, 0x0001C4D5, 0x0000000000000000}, /* QWORDMEMORY */
    {"_SB_.PC09.QR3A.MCTL",        0x5B80, 0x0001C567, 0x0C, 0x0001C56D, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC09.QR3B.MCTL",        0x5B80, 0x0001CDA3, 0x0C, 0x0001CDA9, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC09.QR3C.MCTL",        0x5B80, 0x0001D5DF, 0x0C, 0x0001D5E5, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC09.QR3D.MCTL",        0x5B80, 0x0001DE1B, 0x0C, 0x0001DE21, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC10.FIX1",             0x0011, 0x00000000, 0x88, 0x0001E7EE, 0x0000000000000000}, /* WORDBUSNUMBER */
    {"_SB_.PC10.FIX5",             0x0011, 0x00000000, 0x87, 0x0001E7FE, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC10.FIX2",             0x0011, 0x00000000, 0x88, 0x0001E818, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC10.FIX6",             0x0011, 0x00000000, 0x88, 0x0001E828, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC10.FIX7",             0x0011, 0x00000000, 0x88, 0x0001E838, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC10.FIX3",             0x0011, 0x00000000, 0x87, 0x0001E848, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC10.FIX4",             0x0011, 0x00000000, 0x8A, 0x0001E862, 0x0000000000000000}, /* QWORDMEMORY */
    {"_SB_.PC10.MCP2.MCTL",        0x5B80, 0x0001E8F4, 0x0C, 0x0001E8FA, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC11.FIX1",             0x0011, 0x00000000, 0x88, 0x0001F250, 0x0000000000000000}, /* WORDBUSNUMBER */
    {"_SB_.PC11.FIX5",             0x0011, 0x00000000, 0x87, 0x0001F260, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC11.FIX2",             0x0011, 0x00000000, 0x88, 0x0001F27A, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC11.FIX6",             0x0011, 0x00000000, 0x88, 0x0001F28A, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC11.FIX7",             0x0011, 0x00000000, 0x88, 0x0001F29A, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC11.FIX3",             0x0011, 0x00000000, 0x87, 0x0001F2AA, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC11.FIX4",             0x0011, 0x00000000, 0x8A, 0x0001F2C4, 0x0000000000000000}, /* QWORDMEMORY */
    {"_SB_.PC11.MCP3.MCTL",        0x5B80, 0x0001F356, 0x0C, 0x0001F35C, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC12.FIX1",             0x0011, 0x00000000, 0x88, 0x0002011C, 0x0000000000000000}, /* WORDBUSNUMBER */
    {"_SB_.PC12.FIX5",             0x0011, 0x00000000, 0x87, 0x0002012C, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC12.FIX2",             0x0011, 0x00000000, 0x88, 0x00020146, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC12.FIX6",             0x0011, 0x00000000, 0x88, 0x00020156, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC12.FIX7",             0x0011, 0x00000000, 0x88, 0x00020166, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC12.FIX3",             0x0011, 0x00000000, 0x87, 0x00020176, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC12.FIX4",             0x0011, 0x00000000, 0x8A, 0x00020190, 0x0000000000000000}, /* QWORDMEMORY */
    {"_SB_.PC12.RRP0.MCTL",        0x5B80, 0x0002028C, 0x0C, 0x00020292, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC13.FIX1",             0x0011, 0x00000000, 0x88, 0x00020D07, 0x0000000000000000}, /* WORDBUSNUMBER */
    {"_SB_.PC13.FIX5",             0x0011, 0x00000000, 0x87, 0x00020D17, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC13.FIX2",             0x0011, 0x00000000, 0x88, 0x00020D31, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC13.FIX6",             0x0011, 0x00000000, 0x88, 0x00020D41, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC13.FIX7",             0x0011, 0x00000000, 0x88, 0x00020D51, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC13.FIX3",             0x0011, 0x00000000, 0x87, 0x00020D61, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC13.FIX4",             0x0011, 0x00000000, 0x8A, 0x00020D7B, 0x0000000000000000}, /* QWORDMEMORY */
    {"_SB_.PC13.RR1A.MCTL",        0x5B80, 0x00020E0D, 0x0C, 0x00020E13, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC13.RR1B.MCTL",        0x5B80, 0x00021649, 0x0C, 0x0002164F, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC13.RR1C.MCTL",        0x5B80, 0x00021E85, 0x0C, 0x00021E8B, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC13.RR1D.MCTL",        0x5B80, 0x000226C1, 0x0C, 0x000226C7, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC14.FIX1",             0x0011, 0x00000000, 0x88, 0x0002316F, 0x0000000000000000}, /* WORDBUSNUMBER */
    {"_SB_.PC14.FIX5",             0x0011, 0x00000000, 0x87, 0x0002317F, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC14.FIX2",             0x0011, 0x00000000, 0x88, 0x00023199, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC14.FIX6",             0x0011, 0x00000000, 0x88, 0x000231A9, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC14.FIX7",             0x0011, 0x00000000, 0x88, 0x000231B9, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC14.FIX3",             0x0011, 0x00000000, 0x87, 0x000231C9, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC14.FIX4",             0x0011, 0x00000000, 0x8A, 0x000231E3, 0x0000000000000000}, /* QWORDMEMORY */
    {"_SB_.PC14.RR2A.MCTL",        0x5B80, 0x00023275, 0x0C, 0x0002327B, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC14.RR2B.MCTL",        0x5B80, 0x00023AB1, 0x0C, 0x00023AB7, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC14.RR2C.MCTL",        0x5B80, 0x000242ED, 0x0C, 0x000242F3, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC14.RR2D.MCTL",        0x5B80, 0x00024B29, 0x0C, 0x00024B2F, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC15.FIX1",             0x0011, 0x00000000, 0x88, 0x00025582, 0x0000000000000000}, /* WORDBUSNUMBER */
    {"_SB_.PC15.FIX5",             0x0011, 0x00000000, 0x87, 0x00025592, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC15.FIX2",             0x0011, 0x00000000, 0x88, 0x000255AC, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC15.FIX6",             0x0011, 0x00000000, 0x88, 0x000255BC, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC15.FIX7",             0x0011, 0x00000000, 0x88, 0x000255CC, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC15.FIX3",             0x0011, 0x00000000, 0x87, 0x000255DC, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC15.FIX4",             0x0011, 0x00000000, 0x8A, 0x000255F6, 0x0000000000000000}, /* QWORDMEMORY */
    {"_SB_.PC15.RR3A.MCTL",        0x5B80, 0x00025688, 0x0C, 0x0002568E, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC15.RR3B.MCTL",        0x5B80, 0x00025EC4, 0x0C, 0x00025ECA, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC15.RR3C.MCTL",        0x5B80, 0x00026700, 0x0C, 0x00026706, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC15.RR3D.MCTL",        0x5B80, 0x00026F3C, 0x0C, 0x00026F42, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC16.FIX1",             0x0011, 0x00000000, 0x88, 0x0002790F, 0x0000000000000000}, /* WORDBUSNUMBER */
    {"_SB_.PC16.FIX5",             0x0011, 0x00000000, 0x87, 0x0002791F, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC16.FIX2",             0x0011, 0x00000000, 0x88, 0x00027939, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC16.FIX6",             0x0011, 0x00000000, 0x88, 0x00027949, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC16.FIX7",             0x0011, 0x00000000, 0x88, 0x00027959, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC16.FIX3",             0x0011, 0x00000000, 0x87, 0x00027969, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC16.FIX4",             0x0011, 0x00000000, 0x8A, 0x00027983, 0x0000000000000000}, /* QWORDMEMORY */
    {"_SB_.PC16.MCP4.MCTL",        0x5B80, 0x00027A15, 0x0C, 0x00027A1B, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC17.FIX1",             0x0011, 0x00000000, 0x88, 0x00028371, 0x0000000000000000}, /* WORDBUSNUMBER */
    {"_SB_.PC17.FIX5",             0x0011, 0x00000000, 0x87, 0x00028381, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC17.FIX2",             0x0011, 0x00000000, 0x88, 0x0002839B, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC17.FIX6",             0x0011, 0x00000000, 0x88, 0x000283AB, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC17.FIX7",             0x0011, 0x00000000, 0x88, 0x000283BB, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC17.FIX3",             0x0011, 0x00000000, 0x87, 0x000283CB, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC17.FIX4",             0x0011, 0x00000000, 0x8A, 0x000283E5, 0x0000000000000000}, /* QWORDMEMORY */
    {"_SB_.PC17.MCP5.MCTL",        0x5B80, 0x00028477, 0x0C, 0x0002847D, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC18.FIX1",             0x0011, 0x00000000, 0x88, 0x0002923D, 0x0000000000000000}, /* WORDBUSNUMBER */
    {"_SB_.PC18.FIX5",             0x0011, 0x00000000, 0x87, 0x0002924D, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC18.FIX2",             0x0011, 0x00000000, 0x88, 0x00029267, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC18.FIX6",             0x0011, 0x00000000, 0x88, 0x00029277, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC18.FIX7",             0x0011, 0x00000000, 0x88, 0x00029287, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC18.FIX3",             0x0011, 0x00000000, 0x87, 0x00029297, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC18.FIX4",             0x0011, 0x00000000, 0x8A, 0x000292B1, 0x0000000000000000}, /* QWORDMEMORY */
    {"_SB_.PC18.SRP0.MCTL",        0x5B80, 0x000293AD, 0x0C, 0x000293B3, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC19.FIX1",             0x0011, 0x00000000, 0x88, 0x00029E28, 0x0000000000000000}, /* WORDBUSNUMBER */
    {"_SB_.PC19.FIX5",             0x0011, 0x00000000, 0x87, 0x00029E38, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC19.FIX2",             0x0011, 0x00000000, 0x88, 0x00029E52, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC19.FIX6",             0x0011, 0x00000000, 0x88, 0x00029E62, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC19.FIX7",             0x0011, 0x00000000, 0x88, 0x00029E72, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC19.FIX3",             0x0011, 0x00000000, 0x87, 0x00029E82, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC19.FIX4",             0x0011, 0x00000000, 0x8A, 0x00029E9C, 0x0000000000000000}, /* QWORDMEMORY */
    {"_SB_.PC19.SR1A.MCTL",        0x5B80, 0x00029F2E, 0x0C, 0x00029F34, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC19.SR1B.MCTL",        0x5B80, 0x0002A76A, 0x0C, 0x0002A770, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC19.SR1C.MCTL",        0x5B80, 0x0002AFA6, 0x0C, 0x0002AFAC, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC19.SR1D.MCTL",        0x5B80, 0x0002B7E2, 0x0C, 0x0002B7E8, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC20.FIX1",             0x0011, 0x00000000, 0x88, 0x0002C2B2, 0x0000000000000000}, /* WORDBUSNUMBER */
    {"_SB_.PC20.FIX5",             0x0011, 0x00000000, 0x87, 0x0002C2C2, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC20.FIX2",             0x0011, 0x00000000, 0x88, 0x0002C2DC, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC20.FIX6",             0x0011, 0x00000000, 0x88, 0x0002C2EC, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC20.FIX7",             0x0011, 0x00000000, 0x88, 0x0002C2FC, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC20.FIX3",             0x0011, 0x00000000, 0x87, 0x0002C30C, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC20.FIX4",             0x0011, 0x00000000, 0x8A, 0x0002C326, 0x0000000000000000}, /* QWORDMEMORY */
    {"_SB_.PC20.SR2A.MCTL",        0x5B80, 0x0002C3B8, 0x0C, 0x0002C3BE, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC20.SR2B.MCTL",        0x5B80, 0x0002CBF4, 0x0C, 0x0002CBFA, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC20.SR2C.MCTL",        0x5B80, 0x0002D430, 0x0C, 0x0002D436, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC20.SR2D.MCTL",        0x5B80, 0x0002DC6C, 0x0C, 0x0002DC72, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC21.FIX1",             0x0011, 0x00000000, 0x88, 0x0002E6C5, 0x0000000000000000}, /* WORDBUSNUMBER */
    {"_SB_.PC21.FIX5",             0x0011, 0x00000000, 0x87, 0x0002E6D5, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC21.FIX2",             0x0011, 0x00000000, 0x88, 0x0002E6EF, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC21.FIX6",             0x0011, 0x00000000, 0x88, 0x0002E6FF, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC21.FIX7",             0x0011, 0x00000000, 0x88, 0x0002E70F, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC21.FIX3",             0x0011, 0x00000000, 0x87, 0x0002E71F, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC21.FIX4",             0x0011, 0x00000000, 0x8A, 0x0002E739, 0x0000000000000000}, /* QWORDMEMORY */
    {"_SB_.PC21.SR3A.MCTL",        0x5B80, 0x0002E7CB, 0x0C, 0x0002E7D1, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC21.SR3B.MCTL",        0x5B80, 0x0002F007, 0x0C, 0x0002F00D, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC21.SR3C.MCTL",        0x5B80, 0x0002F843, 0x0C, 0x0002F849, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC21.SR3D.MCTL",        0x5B80, 0x0003007F, 0x0C, 0x00030085, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC22.FIX1",             0x0011, 0x00000000, 0x88, 0x00030A52, 0x0000000000000000}, /* WORDBUSNUMBER */
    {"_SB_.PC22.FIX5",             0x0011, 0x00000000, 0x87, 0x00030A62, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC22.FIX2",             0x0011, 0x00000000, 0x88, 0x00030A7C, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC22.FIX6",             0x0011, 0x00000000, 0x88, 0x00030A8C, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC22.FIX7",             0x0011, 0x00000000, 0x88, 0x00030A9C, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC22.FIX3",             0x0011, 0x00000000, 0x87, 0x00030AAC, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC22.FIX4",             0x0011, 0x00000000, 0x8A, 0x00030AC6, 0x0000000000000000}, /* QWORDMEMORY */
    {"_SB_.PC22.MCP6.MCTL",        0x5B80, 0x00030B58, 0x0C, 0x00030B5E, 0x0000000038584946}, /* OPERATIONREGION */
    {"_SB_.PC23.FIX1",             0x0011, 0x00000000, 0x88, 0x000314B4, 0x0000000000000000}, /* WORDBUSNUMBER */
    {"_SB_.PC23.FIX5",             0x0011, 0x00000000, 0x87, 0x000314C4, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC23.FIX2",             0x0011, 0x00000000, 0x88, 0x000314DE, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC23.FIX6",             0x0011, 0x00000000, 0x88, 0x000314EE, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC23.FIX7",             0x0011, 0x00000000, 0x88, 0x000314FE, 0x0000000000000000}, /* WORDIO */
    {"_SB_.PC23.FIX3",             0x0011, 0x00000000, 0x87, 0x0003150E, 0x0000000000000000}, /* DWORDMEMORY */
    {"_SB_.PC23.FIX4",             0x0011, 0x00000000, 0x8A, 0x00031528, 0x0000000000000000}, /* QWORDMEMORY */
    {"_SB_.PC23.MCP7.MCTL",        0x5B80, 0x000315BA, 0x0C, 0x000315C0, 0x0000000038584946}, /* OPERATIONREGION */
    {NULL,0,0,0,0,0} /* Table terminator */
};

